Struct amazon_sp_aplus_content::models::standard_four_image_text_module::StandardFourImageTextModule
source · [−]pub struct StandardFourImageTextModule {
pub headline: Option<Box<TextComponent>>,
pub block1: Option<Box<StandardImageTextBlock>>,
pub block2: Option<Box<StandardImageTextBlock>>,
pub block3: Option<Box<StandardImageTextBlock>>,
pub block4: Option<Box<StandardImageTextBlock>>,
}Expand description
StandardFourImageTextModule : Four standard images with text, presented across a single row.
Fields
headline: Option<Box<TextComponent>>block1: Option<Box<StandardImageTextBlock>>block2: Option<Box<StandardImageTextBlock>>block3: Option<Box<StandardImageTextBlock>>block4: Option<Box<StandardImageTextBlock>>Implementations
sourceimpl StandardFourImageTextModule
impl StandardFourImageTextModule
sourcepub fn new() -> StandardFourImageTextModule
pub fn new() -> StandardFourImageTextModule
Four standard images with text, presented across a single row.